# Справочник по интерфейсу командной строки

## Основные команды

- `vyro run --app <module:attr>`
- `vyro dev --app <module:attr>`
- `vyro doctor [--strict]`
- `vyro openapi ...`
- `vyro compat ...`
- `vyro release ...`

## Коды выхода

- `0`: успех
- `1`: ошибка выполнения/инструментария/время выполнения.
- `2`: ошибка проверки/использования.